Stan Math Library: stan/math/prim/mat/fun/sum.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

sum.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_SUM_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_SUM_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/arr/fun/sum.hpp>
6 #include <vector>
7
8 namespace stan {
9 namespace math {
10
21 template <typename T, int R, int C>
22 inline double sum(const Eigen::Matrix<T, R, C>& v) {
23 return v.sum();
24 }
25
26 }
27 }
28 #endif
stan::math::sum
fvar< T > sum(const std::vector< fvar< T > > &m)
Return the sum of the entries of the specified standard vector.
Definition: sum.hpp:20
stan
Definition: log_sum_exp.hpp:8
sum.hpp
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.